Schema Docs

Testing $ref

##

Type: object

##

Type: string

Description for object_def/items/propertyA

##

Type: array of string

Description for array_def

#### Each item of this array must be:

Type: string

##

Type: string

##

Type: string

Description for string_def

##

Type: object

##

Type: string

Description for object_def/items/propertyA

##

Type: string

##

Type: object

The delivery is a gift, no prices displayed

##

Type: boolean

##

Type: object

The delivery is a gift, no prices displayed

##

Type: boolean

##

Type: object

The delivery is a gift, no prices displayed

##

Type: boolean

##

Type: object

Test schema with a not

##

#### Must not be:

Type: string

##

Type: object

##

Type: string

Contents of propertyA in final.json